@@ -48,7 +48,6 @@ var showInfoRow = function(t) {
 var hideInfoRow = function(t) {
     row = t.closest('tr').next();
     t = $('.editInfoButtonSelected', t.closest('tr'));
-    console.log(t);
     t.removeClass('editInfoButtonSelected');
     t.addClass('editInfoButton');
     row.hide();
@@ -170,19 +169,19 @@ $(function() {
         var row = t.closest('tr');
         var rows = $('.productImageRow', row.closest('table').find('tbody'));
         var url = row.attr('url');
-        console.log(rows);
         var product_pk = row.attr('product_pk');
         updatePhotos(url, product_pk, rows, function() {
             window.location.reload()
         });
     });
 
-    $('body').on('click', 'a.deleteButton', function(event) {
-        event.preventDefault();
-        row = $(this).closest('.productImageRow');
-        row.fadeOut(function() {
-            row.remove();
-        });
+    $('body').on('click', 'a.imageDeleteButton',
+        function(event) {
+            event.preventDefault();
+            row = $(this).closest('.productImageRow');
+            row.fadeOut(function() {
+                row.remove();
+            });
     })
 
     var limit = 400;
